Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(610)

Unified Diff: dm/DMQuiltTask.h

Issue 256373002: Turn on quilt mode in DM. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: rebase Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dm/DMCpuGMTask.cpp ('k') | dm/DMQuiltTask.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dm/DMQuiltTask.h
diff --git a/dm/DMTileGridTask.h b/dm/DMQuiltTask.h
similarity index 58%
rename from dm/DMTileGridTask.h
rename to dm/DMQuiltTask.h
index 911a1c52a1acf4db98a57578207840c26dfb82b5..56f322f067c68997b6516c32b949faa0fe143f95 100644
--- a/dm/DMTileGridTask.h
+++ b/dm/DMQuiltTask.h
@@ -1,5 +1,5 @@
-#ifndef DMTileGridTask_DEFINED
-#define DMTileGridTask_DEFINED
+#ifndef DMQuiltTask_DEFINED
+#define DMQuiltTask_DEFINED
#include "DMTask.h"
#include "SkBitmap.h"
@@ -11,13 +11,12 @@
namespace DM {
-class TileGridTask : public CpuTask {
+class QuiltTask : public CpuTask {
public:
- TileGridTask(const Task& parent, // TileGridTask must be a child task. Pass its parent here.
- skiagm::GM*, // GM to run through a picture. Takes ownership.
- SkBitmap reference, // Bitmap to compare picture replay results to.
- SkISize tileSize); // Tile size to use.
+ QuiltTask(const Task& parent, // QuiltTask must be a child task. Pass its parent here.
+ skiagm::GM*, // GM to run through a picture. Takes ownership.
+ SkBitmap reference); // Bitmap to compare picture replay results to.
virtual void draw() SK_OVERRIDE;
virtual bool shouldSkip() const SK_OVERRIDE;
@@ -27,7 +26,6 @@ private:
const SkString fName;
SkAutoTDelete<skiagm::GM> fGM;
const SkBitmap fReference;
- const SkISize fTileSize;
};
} // namespace DM
« no previous file with comments | « dm/DMCpuGMTask.cpp ('k') | dm/DMQuiltTask.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698